import { AutoMap } from '@automapper/classes';
import {
  IsOptional,
  IsString,
  IsBoolean,
  IsDate,
  IsInt,
  IsEnum,
} from 'class-validator';
import { Address } from '../entities/address';
import { Frequency } from './frequency.enum';

export class Ad {
  @IsString()
  @AutoMap()
  uuid: string;

  @IsString()
  @AutoMap()
  userUuid: string;

  @IsBoolean()
  @AutoMap()
  driver?: boolean;

  @IsBoolean()
  @AutoMap()
  passenger?: boolean;

  @IsEnum(Frequency)
  @AutoMap()
  frequency: Frequency;

  @IsDate()
  @AutoMap()
  fromDate: Date;

  @IsDate()
  @AutoMap()
  toDate: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  monTime?: string;

  @IsString()
  @IsOptional()
  @AutoMap()
  tueTime?: string;

  @IsString()
  @IsOptional()
  @AutoMap()
  wedTime?: string;

  @IsString()
  @IsOptional()
  @AutoMap()
  thuTime?: string;

  @IsString()
  @IsOptional()
  @AutoMap()
  friTime?: string;

  @IsString()
  @IsOptional()
  @AutoMap()
  satTime?: string;

  @IsString()
  @IsOptional()
  @AutoMap()
  sunTime?: string;

  @IsInt()
  @IsOptional()
  @AutoMap()
  monMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  tueMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  wedMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  thuMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  friMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  satMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  sunMargin?: number;

  @IsInt()
  @AutoMap()
  seatsDriver?: number;

  @IsInt()
  @AutoMap()
  seatsPassenger?: number;

  @IsDate()
  @AutoMap()
  createdAt: Date;

  @IsDate()
  @IsOptional()
  @AutoMap()
  updatedAt?: Date;

  @AutoMap()
  addresses?: Array<Address>;
}
